from typing import Optional
from datetime import datetime
from pydantic import BaseModel

class ItemBase(BaseModel):
    """Base schema for Item."""
    name: str
    description: Optional[str] = None
    is_active: bool = True

class ItemCreate(ItemBase):
    """Schema for creating an Item."""
    pass

class ItemUpdate(BaseModel):
    """Schema for updating an Item."""
    name: Optional[str] = None
    description: Optional[str] = None
    is_active: Optional[bool] = None

class ItemInDBBase(ItemBase):
    """Base schema for Item with DB fields."""
    id: str
    created_at: datetime
    updated_at: datetime

    class Config:
        orm_mode = True

class Item(ItemInDBBase):
    """Schema for returning an Item."""
    pass